﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Kendo.Mvc.Extensions;
using Kendo.Mvc.UI;
using KendoMvcPracticeWeb.Models;
using KendoMvcPracticeWeb.ViewModel;

namespace KendoMvcPracticeWeb.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            return View(new AirlineAirportViewModel());
        }

        public JsonResult GetAirports([DataSourceRequest] DataSourceRequest request)
        {
            var viewModel = GetAirlinesViewModel();
            return Json(viewModel.AirportAirlines.Select(p => new { p.Airport }).Distinct(), JsonRequestBehavior.AllowGet);
        }

        public JsonResult GetAirlines([DataSourceRequest] DataSourceRequest request)
        {
            var viewModel = GetAirlinesViewModel();
            return Json(viewModel.AirportAirlines.Select(p => new { p.Airline }).Distinct(), JsonRequestBehavior.AllowGet);
        }

        [HttpPost]
        public JsonResult GetAirportAirlines([DataSourceRequest] DataSourceRequest request, AirlineAirportViewModel vm)
        {
            IEnumerable<AirportAirline> airportAirlines = GetAirlinesViewModel().AirportAirlines;
            if (vm != null)
            {
                if (vm.SelectedAirlines != null)
                {
                    airportAirlines = airportAirlines.Where(p => vm.SelectedAirlines.Contains(p.Airline));
                }

                if (vm.SelectedAirports != null)
                {
                    airportAirlines = airportAirlines.Where(p => vm.SelectedAirports.Contains(p.Airport));
                }
            }
            
            DataSourceResult dsr = airportAirlines.ToDataSourceResult(request);
            return Json(dsr, JsonRequestBehavior.AllowGet);
        }

        private static AirlineAirportViewModel GetAirlinesViewModel()
        {
            var viewModel = new AirlineAirportViewModel();
            viewModel.AirportAirlines = new List<AirportAirline>();
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 2, Airline = "Delta", Airport = "EWR" });
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 3, Airline = "SouthWest", Airport = "ATL" });
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 5, Airline = "United", Airport = "JFK" });
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 6, Airline = "Delta", Airport = "ATL" });
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 7, Airline = "JetBlue", Airport = "SFO" });
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 8, Airline = "Delta", Airport = "ATL" });
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 9, Airline = "United", Airport = "EWR" });
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 10, Airline = "United", Airport = "SFO" });
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 11, Airline = "JetBlue", Airport = "ATL" });
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 12, Airline = "Southwest", Airport = "JFK" });
            viewModel.AirportAirlines.Add(new AirportAirline() { Id = 13, Airline = "United", Airport = "ATL" });
            return viewModel;
        }
    }
}
